@@ -27,11 +27,11 @@ from typing import (
 
 import docstring_parser
 import typing_extensions
-from typing_extensions import Annotated, get_args, get_type_hints, is_typeddict
+from typing_extensions import get_args, get_type_hints, is_typeddict
 
 from . import conf  # Avoid circular import.
 from . import _docstrings, _instantiators, _resolver, _singleton, _strings
-from .conf import _markers
+from .conf import _confstruct, _markers
 
 # Support attrs and pydantic if they're installed.
 try:
@@ -52,10 +52,11 @@ class FieldDefinition:
     helptext: Optional[str]
     markers: FrozenSet[_markers.Marker]
 
-    # Override the name in our kwargs. Currently only used for dictionary types when
-    # the key values aren't strings, but in the future could be used whenever the
-    # user-facing argument name doesn't match the keyword expected by our callable.
-    name_override: Optional[Any]
+    argconf: _confstruct._ArgConfiguration
+
+    # Override the name in our kwargs. Useful whenever the user-facing argument name
+    # doesn't match the keyword expected by our callable.
+    call_argname: Any
 
     def __post_init__(self):
         if (
@@ -71,30 +72,38 @@ class FieldDefinition:
         typ: Type,
         default: Any,
         helptext: Optional[str],
+        call_argname_override: Optional[Any] = None,
         *,
         markers: Tuple[_markers.Marker, ...] = (),
-        name_override: Optional[Any] = None,
     ):
-        _, inferred_markers = _resolver.unwrap_annotated(typ, _markers.Marker)
+        # Try to extract argconf overrides from type.
+        _, argconfs = _resolver.unwrap_annotated(typ, _confstruct._ArgConfiguration)
+        if len(argconfs) == 0:
+            argconf = _confstruct._ArgConfiguration(None, None, None)
+        else:
+            assert len(argconfs) == 1
+            (argconf,) = argconfs
+            helptext = argconf.help
+
+        typ, inferred_markers = _resolver.unwrap_annotated(typ, _markers.Marker)
         return FieldDefinition(
-            name,
+            name if argconf.name is None else argconf.name,
             typ,
             default,
             helptext,
             frozenset(inferred_markers).union(markers),
-            name_override,
+            argconf,
+            call_argname_override if call_argname_override is not None else name,
         )
 
     def add_markers(self, markers: Tuple[_markers.Marker, ...]) -> FieldDefinition:
-        if len(markers) == 0:
-            return self
         return dataclasses.replace(
             self,
-            typ=Annotated.__class_getitem__((self.typ,) + markers),  # type: ignore
             markers=self.markers.union(markers),
         )
 
     def is_positional(self) -> bool:
+        """Returns True if the argument should be positional in the commandline."""
         return (
             # Explicit positionals.
             _markers.Positional in self.markers
@@ -102,6 +111,15 @@ class FieldDefinition:
             or self.name == _strings.dummy_field_name
         )
 
+    def is_positional_call(self) -> bool:
+        """Returns True if the argument should be positional in underlying Python call."""
+        return (
+            # Explicit positionals.
+            _markers._PositionalCall in self.markers
+            # Dummy dataclasses should have a single positional field.
+            or self.name == _strings.dummy_field_name
+        )
+
 
 class PropagatingMissingType(_singleton.Singleton):
     pass
@@ -204,7 +222,7 @@ def _try_field_list_from_callable(
     default_instance: _DefaultInstance,
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     f, found_subcommand_configs = _resolver.unwrap_annotated(
-        f, conf._subcommands._SubcommandConfiguration
+        f, conf._confstruct._SubcommandConfiguration
     )
     if len(found_subcommand_configs) > 0:
         default_instance = found_subcommand_configs[0].default
@@ -365,12 +383,23 @@ def _try_field_list_from_dataclass(
     field_list = []
     for dc_field in filter(lambda field: field.init, _resolver.resolved_fields(cls)):
         default = _get_dataclass_field_default(dc_field, default_instance)
+
+        # Try to get helptext from field metadata. This is also intended to be
+        # compatible with HuggingFace-style config objects.
+        helptext = dc_field.metadata.get("help", None)
+        assert isinstance(helptext, (str, type(None)))
+
+        # Try to get helptext from docstrings. Note that this can't be generated
+        # dynamically.
+        if helptext is None:
+            helptext = _docstrings.get_field_docstring(cls, dc_field.name)
+
         field_list.append(
             FieldDefinition.make(
                 name=dc_field.name,
                 typ=dc_field.type,
                 default=default,
-                helptext=_docstrings.get_field_docstring(cls, dc_field.name),
+                helptext=helptext,
             )
         )
     return field_list
@@ -545,7 +574,7 @@ def _try_field_list_from_dict(
                 default=v,
                 helptext=None,
                 # Dictionary specific key:
-                name_override=k,
+                call_argname_override=k,
             )
         )
     return field_list
@@ -628,7 +657,7 @@ def _field_list_from_params(
                 typ=hints[param.name],
                 default=default,
                 helptext=helptext,
-                markers=(_markers.Positional,)
+                markers=(_markers.Positional, _markers._PositionalCall)
                 if param.kind is inspect.Parameter.POSITIONAL_ONLY
                 else (),
             )
